/// <reference types="react" />
import typographyTokens from '@highlight-ui/tokens/dist/typography/typography.json';
import typographyColorTokens from '@highlight-ui/tokens/dist/typography/colors.json';
import typographyFontFamilyTokens from '@highlight-ui/tokens/dist/typography/fontFamilies.json';
import typographyFontSizeTokens from '@highlight-ui/tokens/dist/typography/fontSizes.json';
import typographyFontWeightTokens from '@highlight-ui/tokens/dist/typography/fontWeights.json';
import typographyTextCaseTokens from '@highlight-ui/tokens/dist/typography/textCase.json';
import typographyTextDecorationTokens from '@highlight-ui/tokens/dist/typography/textDecoration.json';
import typographyLetterSpacingTokens from '@highlight-ui/tokens/dist/typography/letterSpacing.json';
import typographyLineHeightTokens from '@highlight-ui/tokens/dist/typography/lineHeights.json';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type TypographyToken = keyof typeof typographyTokens;
export declare type TypographyColorToken = keyof typeof typographyColorTokens;
export declare type TypographyFontFamilyToken = keyof typeof typographyFontFamilyTokens;
export declare type TypographyFontSizeToken = keyof typeof typographyFontSizeTokens;
export declare type TypographyFontWeightToken = keyof typeof typographyFontWeightTokens;
export declare type TypographyTextCaseToken = keyof typeof typographyTextCaseTokens;
export declare type TypographyTextDecorationToken = keyof typeof typographyTextDecorationTokens;
export declare type TypographyLetterSpacingToken = keyof typeof typographyLetterSpacingTokens;
export declare type TypographyLineHeightToken = keyof typeof typographyLineHeightTokens;
declare type TypographyVariant = 'heading-1' | 'heading-2' | 'heading-3' | 'heading-4' | 'subtitle-1' | 'subtitle-2' | 'subtitle-3' | 'subtitle-4' | 'body-1' | 'button-1' | 'caption-1' | 'caption-2' | 'overline-1';
export declare type DeprecatedTypographyProps = React.PropsWithChildren<{
    /** Allows providing a custom class name */
    className?: string;
    /** Specifies an HTML tag for rendering the element */
    component?: string;
    /** Specifies a color of the typography */
    color?: TypographyColorToken;
    /**
     * @deprecated This variant prop is deprecated and will be removed in a future release. Please use token prop.
     */
    variant?: TypographyVariant;
} & React.HTMLAttributes<HTMLElement> & React.ButtonHTMLAttributes<HTMLElement>>;
export declare type TokenisedTypographyProps = Omit<DeprecatedTypographyProps, 'variant'> & PropsWithMetadata<{
    /** Specifies typography token (Ignores `variant` if specified) */
    token: TypographyToken;
    /** Specifies font family (Ignored if `variant` is specified) */
    fontFamily?: TypographyFontFamilyToken;
    /** Specifies font size (Ignored if `variant` is specified) */
    fontSize?: TypographyFontSizeToken;
    /** Specifies font weight (Ignored if `variant` is specified) */
    fontWeight?: TypographyFontWeightToken;
    /** Specifies letter spacing (Ignored if `variant` is specified) */
    letterSpacing?: TypographyLetterSpacingToken;
    /** Specifies line height (Ignored if `variant` is specified) */
    lineHeight?: TypographyLineHeightToken;
    /** Specifies text case (Ignored if `variant` is specified) */
    textTransform?: TypographyTextCaseToken;
    /** Specifies text decoration (Ignored if `variant` is specified) */
    textDecoration?: TypographyTextDecorationToken;
}>;
export declare type TypographyProps = DeprecatedTypographyProps & Omit<TokenisedTypographyProps, 'token'> & Partial<Pick<TokenisedTypographyProps, 'token'>>;
export {};
